@@ -434,7 +434,7 @@ class Deploy(object):
                 
             elif 'tar.gz' in name and 's3' not in name:
                 
-                self.makedir_safe("downloads")
+                self.makedir_safe("./downloads/{}/".format(i))
                 shutil.copy(name, "./downloads/{}/".format(i))
                 
                 with tarfile.open(
